@@ -5,12 +5,8 @@ import json
 import pandas as pd
 
 
-def f1():
-    print('1')
-
-
 def version():
-    return '1.1.0'
+    return '1.1.1'
 
 
 def conv_queryset_ls_to_serialzer_ls(qs: list):
